@@ -18,12 +18,12 @@
 #ifndef KDIFF3_H
 #define KDIFF3_H
 
-#include "diff.h"
-
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
+#include "diff.h"
+
 // include files for TQt
 #include <tqdialog.h>
 #include <tqsplitter.h>
