@@ -33,14 +33,14 @@
 #include <tqvbuttongroup.h>
 #include <tqsettings.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcolorbtn.h>
-#include <kfontdialog.h> // For KFontChooser
+#include <tdefontdialog.h> // For TDEFontChooser
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <kmainwindow.h> //For ktoolbar.h
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
+#include <tdemainwindow.h> //For tdetoolbar.h
 
 //#include <kkeydialog.h>
 #include <map>
@@ -52,7 +52,7 @@
 #include <iostream>
 
 #ifndef KREPLACEMENTS_H
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #endif
 
 static TQString s_historyEntryStartRegExpToolTip;
@@ -168,11 +168,11 @@ typedef OptionT<TQPoint> OptionPoint;
 typedef OptionT<TQSize> OptionSize;
 typedef OptionT<TQStringList> OptionStringList;
 
-class OptionFontChooser : public KFontChooser, public OptionItem
+class OptionFontChooser : public TDEFontChooser, public OptionItem
 {
 public:
    OptionFontChooser( const TQFont& defaultVal, const TQString& saveName, TQFont* pbVar, TQWidget* pParent, OptionDialog* pOD )
-   :KFontChooser( pParent,"font",true/*onlyFixed*/,TQStringList(),false,6 ),
+   :TDEFontChooser( pParent,"font",true/*onlyFixed*/,TQStringList(),false,6 ),
     OptionItem( pOD, saveName )
    {
       m_pbVar = pbVar;
@@ -494,7 +494,7 @@ void OptionDialog::setupOtherOptions()
    new OptionToggleAction( true,  "Show Toolbar", &m_bShowToolBar, this );
    new OptionToggleAction( true,  "Show Statusbar", &m_bShowStatusBar, this );
 
-   new OptionNum( (int)KToolBar::Top, "ToolBarPos", &m_toolBarPos, this );
+   new OptionNum( (int)TDEToolBar::Top, "ToolBarPos", &m_toolBarPos, this );
    new OptionSize( TQSize(600,400),"Geometry", &m_geometry, this );
    new OptionPoint( TQPoint(0,22), "Position", &m_position, this );
    new OptionToggleAction( false, "WindowStateMaximised", &m_bMaximised, this );
@@ -508,7 +508,7 @@ void OptionDialog::setupOtherOptions()
 void OptionDialog::setupFontPage( void )
 {
    TQFrame *page = addPage( i18n("Font"), i18n("Editor & Diff Output Font" ),
-                             BarIcon("fonts", KIcon::SizeMedium ) );
+                             BarIcon("fonts", TDEIcon::SizeMedium ) );
 
    TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
@@ -518,7 +518,7 @@ void OptionDialog::setupFontPage( void )
 #elif defined( KREPLACEMENTS_H )
       TQFont("Courier", 10 );
 #else
-      KGlobalSettings::fixedFont();
+      TDEGlobalSettings::fixedFont();
 #endif
 
    OptionFontChooser* pFontChooser = new OptionFontChooser( defaultFont, "Font", &m_font, page, this );
@@ -540,7 +540,7 @@ void OptionDialog::setupFontPage( void )
 void OptionDialog::setupColorPage( void )
 {
   TQFrame *page = addPage( i18n("Color"), i18n("Colors Settings"),
-     BarIcon("colorize", KIcon::SizeMedium ) );
+     BarIcon("colorize", TDEIcon::SizeMedium ) );
   TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
   TQGridLayout *gbox = new TQGridLayout( 7, 2 );
@@ -668,7 +668,7 @@ void OptionDialog::setupColorPage( void )
 void OptionDialog::setupEditPage( void )
 {
    TQFrame *page = addPage( i18n("Editor"), i18n("Editor Behavior"),
-                           BarIcon("edit", KIcon::SizeMedium ) );
+                           BarIcon("edit", TDEIcon::SizeMedium ) );
    TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
    TQGridLayout *gbox = new TQGridLayout( 4, 2 );
@@ -730,7 +730,7 @@ void OptionDialog::setupEditPage( void )
 void OptionDialog::setupDiffPage( void )
 {
    TQFrame *page = addPage( i18n("Diff"), i18n("Diff Settings"),
-                           BarIcon("misc", KIcon::SizeMedium ) );
+                           BarIcon("misc", TDEIcon::SizeMedium ) );
    TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
    TQGridLayout *gbox = new TQGridLayout( 3, 2 );
@@ -798,7 +798,7 @@ void OptionDialog::setupDiffPage( void )
 void OptionDialog::setupMergePage( void )
 {
    TQFrame *page = addPage( i18n("Merge"), i18n("Merge Settings"),
-                           BarIcon("misc", KIcon::SizeMedium ) );
+                           BarIcon("misc", TDEIcon::SizeMedium ) );
    TQVBoxLayout *topLayout = new TQVBoxLayout( page );
    topLayout->setMargin( 5 );
    topLayout->setSpacing( spacingHint() );
@@ -981,7 +981,7 @@ void OptionDialog::setupMergePage( void )
 void OptionDialog::setupDirectoryMergePage( void )
 {
    TQFrame *page = addPage( i18n("Directory Merge"), i18n("Directory Merge"),
-                           BarIcon("folder", KIcon::SizeMedium ) );
+                           BarIcon("folder", TDEIcon::SizeMedium ) );
    TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
    TQGridLayout *gbox = new TQGridLayout( 11, 2 );
@@ -1211,7 +1211,7 @@ void OptionDialog::setupRegionalPage( void )
    new Utf8BOMCodec();
 
    TQFrame *page = addPage( i18n("Regional Settings"), i18n("Regional Settings"),
-                           BarIcon("locale"/*"charset"*/, KIcon::SizeMedium ) );
+                           BarIcon("locale"/*"charset"*/, TDEIcon::SizeMedium ) );
    TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
    TQGridLayout *gbox = new TQGridLayout( 3, 2 );
@@ -1441,7 +1441,7 @@ static char* countryMap[]={
 void OptionDialog::setupIntegrationPage( void )
 {
    TQFrame *page = addPage( i18n("Integration"), i18n("Integration Settings"),
-                           BarIcon("launch"/*"charset"*/, KIcon::SizeMedium ) );
+                           BarIcon("launch"/*"charset"*/, TDEIcon::SizeMedium ) );
    TQVBoxLayout *topLayout = new TQVBoxLayout( page, 5, spacingHint() );
 
    TQGridLayout *gbox = new TQGridLayout( 3, 3 );
@@ -1537,10 +1537,10 @@ void OptionDialog::slotEncodingChanged()
 void OptionDialog::setupKeysPage( void )
 {
    //TQVBox *page = addVBoxPage( i18n("Keys"), i18n("KeyDialog" ),
-   //                          BarIcon("fonts", KIcon::SizeMedium ) );
+   //                          BarIcon("fonts", TDEIcon::SizeMedium ) );
 
    //TQVBoxLayout *topLayout = new TQVBoxLayout( page, 0, spacingHint() );
-    //           new KFontChooser( page,"font",false/*onlyFixed*/,TQStringList(),false,6 );
+    //           new TDEFontChooser( page,"font",false/*onlyFixed*/,TQStringList(),false,6 );
    //m_pKeyDialog=new KKeyDialog( false, 0 );
    //topLayout->addWidget( m_pKeyDialog );
 }
@@ -1627,9 +1627,9 @@ void OptionDialog::setState()
 class ConfigValueMap : public ValueMap
 {
 private:
-   KConfig* m_pConfig;
+   TDEConfig* m_pConfig;
 public:
-   ConfigValueMap( KConfig* pConfig ) { m_pConfig = pConfig; }
+   ConfigValueMap( TDEConfig* pConfig ) { m_pConfig = pConfig; }
 
    void writeEntry(const TQString& s, const TQFont&  v ){ m_pConfig->writeEntry(s,v); }
    void writeEntry(const TQString& s, const TQColor& v ){ m_pConfig->writeEntry(s,v); }
@@ -1651,7 +1651,7 @@ public:
    TQString     readEntry     (const TQString& s, const TQString& defaultVal){ return m_pConfig->readEntry(s,defaultVal); }
 };
 
-void OptionDialog::saveOptions( KConfig* config )
+void OptionDialog::saveOptions( TDEConfig* config )
 {
    // No i18n()-Translations here!
 
@@ -1665,7 +1665,7 @@ void OptionDialog::saveOptions( KConfig* config )
    }
 }
 
-void OptionDialog::readOptions( KConfig* config )
+void OptionDialog::readOptions( TDEConfig* config )
 {
    // No i18n()-Translations here!
 
