@@ -25,9 +25,9 @@
 #include <ctype.h>
 #include <tqaccel.h>
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kfontdialog.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdefontdialog.h>
 #include <kstatusbar.h>
 #include <kkeydialog.h>
 
